==> hesperides-cli-0.1.0.tar.gz: hesperides-cli-0.1.0/hesperidescli/applications/platforms/snapshots/snapshots.py <==
import click

from hesperidescli import utils
from hesperidescli.client import Client


@click.command('get-snapshots')
@click.option('--application_name')
@click.option('--platform_name')
def get_snapshots(application_name, platform_name):
    if application_name is None:
        print('--application_name required')
        return ''
    if platform_name is None:
        print('--platform_name required')
        return ''
    client = Client()
    response = client.get('/rest/applications/' + application_name + '/platforms/' + platform_name + '/snapshots')
    utils.pretty_print(response)


@click.command('restore-snapshot')
@click.option('--application_name')
@click.option('--platform_name')
def restore_snapshot(application_name, platform_name):
    if application_name is None:
        print('--application_name required')
        return ''
    if platform_name is None:
        print('--platform_name required')
        return ''
    client = Client()
    response = client.post(
        '/rest/applications/' + application_name + '/platforms/' + platform_name + '/restore_snapshot')
    utils.pretty_print(response)


@click.command('take-snapshot')
@click.option('--application_name')
@click.option('--platform_name')
@click.option('--body')
def take_snapshot(application_name, platform_name, body):
    if application_name is None:
        print('--application_name required')
        return ''
    if platform_name is None:
        print('--platform_name required')
        return ''
    if body is None:
        print('--body required')
        return ''
    file = open(body, "r")
    file_body = file.read()
    file.close()
    client = Client()
    response = client.post(
        '/rest/applications/' + application_name + '/platforms/' + platform_name + '/take_snapshot', file_body)
    utils.pretty_print(response)

==> hesperides-cli-0.2.1.tar.gz: hesperides-cli-0.2.1/hesperidescli/applications/platforms/snapshots/snapshots.py <==
import click

from hesperidescli import utils
from hesperidescli.client import Client


@click.command('get-application-platform-snapshots')
@click.option('--application_name')
@click.option('--platform_name')
def get_application_platform_snapshots(application_name, platform_name):
    if application_name is None:
        print('--application_name required')
        return ''
    if platform_name is None:
        print('--platform_name required')
        return ''
    client = Client()
    response = client.get('/rest/applications/' + application_name + '/platforms/' + platform_name + '/snapshots')
    utils.pretty_print(response)


@click.command('restore-application-platform-snapshots')
@click.option('--application_name')
@click.option('--platform_name')
def restore_application_platform_snapshots(application_name, platform_name):
    if application_name is None:
        print('--application_name required')
        return ''
    if platform_name is None:
        print('--platform_name required')
        return ''
    client = Client()
    response = client.post(
        '/rest/applications/' + application_name + '/platforms/' + platform_name + '/restore_snapshot')
    utils.pretty_print(response)


@click.command('take-application-platform-snapshot')
@click.option('--application_name')
@click.option('--platform_name')
@click.option('--body')
def take_application_platform_snapshot(application_name, platform_name, body):
    if application_name is None:
        print('--application_name required')
        return ''
    if platform_name is None:
        print('--platform_name required')
        return ''
    if body is None:
        print('--body required')
        return ''
    file = open(body, "r")
    file_body = file.read()
    file.close()
    client = Client()
    response = client.post(
        '/rest/applications/' + application_name + '/platforms/' + platform_name + '/take_snapshot', file_body)
    utils.pretty_print(response)
